@@ -33,7 +33,6 @@
 
 #include "logModeItemBuilder.h"
 #include "logViewWidget.h"
-#include "logViewWidgetItem.h"
 
 #include "logMode.h"
 
@@ -60,7 +59,7 @@ void LogViewWidgetItem::toggleToolTip(bool displayed)
     if (displayed == true)
         setToolTip(columnCount() - 1, line->logMode()->itemBuilder()->createToolTipText(line));
     else
-        setToolTip(columnCount() - 1, QLatin1String(""));
+        setToolTip(columnCount() - 1, QString());
 }
 
 bool LogViewWidgetItem::operator<(const QTreeWidgetItem &other) const
